@@ -3,18 +3,19 @@
 # Picard, the next-generation MusicBrainz tagger
 #
 # Copyright (C) 2006-2008, 2011-2014 Lukáš Lalinský
-# Copyright (C) 2009, 2018-2022 Philipp Wolfer
+# Copyright (C) 2009, 2018-2023 Philipp Wolfer
 # Copyright (C) 2012 Chad Wilson
 # Copyright (C) 2012-2013 Michael Wiencek
-# Copyright (C) 2013-2021 Laurent Monin
+# Copyright (C) 2013-2022 Laurent Monin
 # Copyright (C) 2015 Ohm Patel
 # Copyright (C) 2015 Sophist-UK
 # Copyright (C) 2016 Suhas
 # Copyright (C) 2016-2017 Wieland Hoffmann
 # Copyright (C) 2016-2018 Sambhav Kothari
 # Copyright (C) 2017 Ville Skyttä
-# Copyright (C) 2018, 2021 Bob Swift
+# Copyright (C) 2018, 2021, 2023 Bob Swift
 # Copyright (C) 2021 Gabriel Ferreira
+# Copyright (C) 2022 skelly37
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -31,10 +32,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 
-from picard.version import (
-    Version,
-    VersionError,
-)
+from picard.version import Version
 
 
 PICARD_ORG_NAME = "MusicBrainz"
@@ -42,7 +40,7 @@ PICARD_APP_NAME = "Picard"
 PICARD_DISPLAY_NAME = "MusicBrainz Picard"
 PICARD_APP_ID = "org.musicbrainz.Picard"
 PICARD_DESKTOP_NAME = PICARD_APP_ID + ".desktop"
-PICARD_VERSION = Version(2, 8, 5, 'final', 0)
+PICARD_VERSION = Version(2, 12, 3, 'final', 0)
 
 
 # optional build version
@@ -51,20 +49,6 @@ PICARD_VERSION = Version(2, 8, 5, 'final', 0)
 PICARD_BUILD_VERSION_STR = ""
 
 
-def version_to_string(version, short=False):
-    """Deprecated: Use picard.version.Version.to_string instead"""
-    if len(version) != 5:
-        raise VersionError("Length != 5")
-    if not isinstance(version, Version):
-        version = Version(*version)
-    return version.to_string(short=short)
-
-
-def version_from_string(version_str):
-    """Deprecated: Use picard.version.Version.from_string instead"""
-    return Version.from_string(version_str)
-
-
 PICARD_VERSION_STR = PICARD_VERSION.to_string()
 PICARD_VERSION_STR_SHORT = PICARD_VERSION.to_string(short=True)
 if PICARD_BUILD_VERSION_STR:
@@ -86,6 +70,10 @@ api_versions = [
     "2.6",
     "2.7",
     "2.8",
+    "2.9",
+    "2.10",
+    "2.11",
+    "2.12",
 ]
 
 api_versions_tuple = [Version.from_string(v) for v in api_versions]
@@ -119,8 +107,15 @@ def crash_handler():
 
     # Display the crash information to the user as a dialog. This requires
     # importing Qt5 and has some potential to fail if things are broken.
-    from PyQt5.QtCore import QCoreApplication, Qt, QUrl
-    from PyQt5.QtWidgets import QApplication, QMessageBox
+    from PyQt5.QtCore import (
+        QCoreApplication,
+        Qt,
+        QUrl,
+    )
+    from PyQt5.QtWidgets import (
+        QApplication,
+        QMessageBox,
+    )
     app = QCoreApplication.instance()
     if not app:
         app = QApplication(sys.argv)
