@@ -2,9 +2,9 @@
 #
 # Picard, the next-generation MusicBrainz tagger
 #
-# Copyright (C) 2008, 2018-2021 Philipp Wolfer
+# Copyright (C) 2008, 2018-2022 Philipp Wolfer
 # Copyright (C) 2011, 2013 Michael Wiencek
-# Copyright (C) 2013, 2018, 2020-2021 Laurent Monin
+# Copyright (C) 2013, 2018, 2020-2022 Laurent Monin
 # Copyright (C) 2016-2017 Sambhav Kothari
 # Copyright (C) 2018 Vishal Choudhary
 #
@@ -39,9 +39,9 @@ class RatingWidget(QtWidgets.QWidget):
         super().__init__(parent)
         self._track = track
         config = get_config()
-        self._maximum = config.setting["rating_steps"] - 1
+        self._maximum = config.setting['rating_steps'] - 1
         try:
-            self._rating = int(track.metadata["~rating"] or 0)
+            self._rating = int(track.metadata['~rating'] or 0)
         except ValueError:
             self._rating = 0
         self._highlight = 0
@@ -54,7 +54,7 @@ class RatingWidget(QtWidgets.QWidget):
         self._height = self._star_size + 6
         self.setMaximumSize(self._width, self._height)
         self.setMinimumSize(self._width, self._height)
-        self.setSizePolicy(QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed))
+        self.setSizePolicy(QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed))
         self.setMouseTracking(True)
 
     def sizeHint(self):
@@ -67,7 +67,7 @@ class RatingWidget(QtWidgets.QWidget):
             self.update()
 
     def mousePressEvent(self, event):
-        if event.button() == QtCore.Qt.LeftButton:
+        if event.button() == QtCore.Qt.MouseButton.LeftButton:
             x = event.x()
             if x < self._offset:
                 return
@@ -93,17 +93,26 @@ class RatingWidget(QtWidgets.QWidget):
             rating = self._maximum
         return rating
 
+    def _submitted(self, document, http, error):
+        if error:
+            self.tagger.window.set_statusbar_message(
+                N_("Failed to submit rating for track '%(track_title)s' due to server error %(error)d"),
+                {'track_title': self._track.metadata['title'], 'error': error},
+                echo=None,
+            )
+            log.error("Failed to submit rating for %s (server HTTP error %d)", self._track, error)
+
     def _update_track(self):
         track = self._track
         rating = str(self._rating)
-        track.metadata["~rating"] = rating
+        track.metadata['~rating'] = rating
         for file in track.files:
-            file.metadata["~rating"] = rating
+            file.metadata['~rating'] = rating
         config = get_config()
-        if config.setting["submit_ratings"]:
-            ratings = {("recording", track.id): self._rating}
+        if config.setting['submit_ratings']:
+            ratings = {('recording', track.id): self._rating}
             try:
-                self.tagger.mb_api.submit_ratings(ratings, None)
+                self.tagger.mb_api.submit_ratings(ratings, self._submitted)
             except ValueError:  # This should never happen as self._rating is always an integer
                 log.error("Failed to submit rating for recording %s", track.id, exc_info=True)
 
