@@ -40,7 +40,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
-
+try:
+    from charset_normalizer import detect
+except ImportError:
+    try:
+        from chardet import detect
+    except ImportError:
+        detect = None
 from collections import (
     defaultdict,
     namedtuple,
@@ -48,7 +54,6 @@ from collections import (
 from collections.abc import Mapping
 from itertools import chain
 import json
-from locale import strxfrm as _strxfrm
 import ntpath
 from operator import attrgetter
 import os
@@ -245,7 +250,7 @@ def system_supports_long_paths():
         system_supports_long_paths._supported = supported
         return supported
     except OSError:
-        log.info('Failed reading LongPathsEnabled from registry')
+        log.info("Failed reading LongPathsEnabled from registry")
         return False
 
 
@@ -257,7 +262,7 @@ def normpath(path):
         # realpath can fail if path does not exist or is not accessible
         # or on Windows if drives are mounted without mount manager
         # (see https://tickets.metabrainz.org/browse/PICARD-2425).
-        log.warning('Failed getting realpath for "%s": %s', path, why)
+        log.warning("Failed getting realpath for `%s`: %s", path, why)
     # If the path is longer than 259 characters on Windows, prepend the \\?\
     # prefix. This enables access to long paths using the Windows API. See
     # https://docs.microsoft.com/en-us/windows/win32/fileio/maximum-file-path-limitation
@@ -267,8 +272,16 @@ def normpath(path):
 
 
 def win_prefix_longpath(path):
+    """
+    For paths longer then WIN_MAX_FILEPATH_LEN enable long path support by prefixing with WIN_LONGPATH_PREFIX.
+
+    See https://learn.microsoft.com/en-us/windows/win32/fileio/maximum-file-path-limitation
+    """
     if len(path) > WIN_MAX_FILEPATH_LEN and not path.startswith(WIN_LONGPATH_PREFIX):
-        path = WIN_LONGPATH_PREFIX + path
+        if path.startswith(r'\\'):  # UNC path
+            path = WIN_LONGPATH_PREFIX + 'UNC' + path[1:]
+        else:
+            path = WIN_LONGPATH_PREFIX + path
     return path
 
 
@@ -392,7 +405,7 @@ def translate_from_sortname(name, sortname):
     """'Translate' the artist name by reversing the sortname."""
     for c in name:
         ctg = unicodedata.category(c)
-        if ctg[0] == "L" and unicodedata.name(c).find("LATIN") == -1:
+        if ctg[0] == "L" and unicodedata.name(c).find('LATIN') == -1:
             for separator in (" & ", "; ", " and ", " vs. ", " with ", " y "):
                 if separator in sortname:
                     parts = sortname.split(separator)
@@ -741,11 +754,11 @@ def build_qurl(host, port=80, path=None, queryargs=None):
     url.setHost(host)
 
     if port == 443 or host in MUSICBRAINZ_SERVERS:
-        url.setScheme("https")
+        url.setScheme('https')
     elif port == 80:
-        url.setScheme("http")
+        url.setScheme('http')
     else:
-        url.setScheme("http")
+        url.setScheme('http')
         url.setPort(port)
 
     if path is not None:
@@ -897,21 +910,22 @@ def find_best_match(candidates, no_match):
     return BestMatch(similarity=best_match.similarity, result=best_match)
 
 
-def get_qt_enum(cls, enum):
+def get_qt_enum(cls, attr_class):
     """
-    List all the names of attributes inside a Qt enum.
+    Generate all the names of attributes inside a class that are instances of a specific class
+
+    Args:
+        cls: the class in which to search attributes
+        attr_class: class of attributes to match
 
     Example:
         >>> from PyQt5.Qt import Qt
-        >>> print(get_qt_enum(Qt, Qt.CoordinateSystem))
+        >>> print(list(get_qt_enum(Qt, Qt.CoordinateSystem)))
         ['DeviceCoordinates', 'LogicalCoordinates']
     """
-    values = []
     for key in dir(cls):
-        value = getattr(cls, key)
-        if isinstance(value, enum):
-            values.append(key)
-    return values
+        if isinstance(getattr(cls, key), attr_class):
+            yield key
 
 
 def limited_join(a_list, limit, join_string='+', middle_string='…'):
@@ -1093,7 +1107,7 @@ def unique_numbered_title(default_title, existing_titles, fmt=None):
        based on given default title and existing titles
     """
     if fmt is None:
-        fmt = _(DEFAULT_NUMBERED_TITLE_FORMAT)
+        fmt = gettext_constants(DEFAULT_NUMBERED_TITLE_FORMAT)
 
     escaped_title = re.escape(default_title)
     reg_count = r'(\d+)'
@@ -1116,7 +1130,7 @@ def get_base_title_with_suffix(title, suffix, fmt=None):
        removing the suffix and number portion from the end.
     """
     if fmt is None:
-        fmt = _(DEFAULT_NUMBERED_TITLE_FORMAT)
+        fmt = gettext_constants(DEFAULT_NUMBERED_TITLE_FORMAT)
 
     escaped_suffix = re.escape(suffix)
     reg_title = r'(?P<title>.*?)(?:\s*' + escaped_suffix + ')?'
@@ -1131,7 +1145,7 @@ def get_base_title_with_suffix(title, suffix, fmt=None):
 def get_base_title(title):
     """Extract the base portion of a title, using the standard suffix.
     """
-    suffix = _(DEFAULT_COPY_TEXT)
+    suffix = gettext_constants(DEFAULT_COPY_TEXT)
     return get_base_title_with_suffix(title, suffix)
 
 
@@ -1150,40 +1164,25 @@ def any_exception_isinstance(error, type_):
     return any(isinstance(err, type_) for err in iter_exception_chain(error))
 
 
-def strxfrm(string):
-    """Transforms a string to one that can be used in locale-aware comparisons.
-
-    Wrapper around locale.strxfrm, that never throws OSError or ValueError. If an
-    error occurs this function will return the string converted to lower case.
-    Also null bytes in the input string will be ignored.
-
-    Args:
-        string: The string to convert
-
-    Returns: A string that can be compared locale-aware
-    """
-    try:
-        return _strxfrm(string.replace('\0', ''))
-    except (OSError, ValueError) as err:
-        log.warning('strxfrm(%r) failed: %r', string, err)
-        return string.lower()
-
-
 ENCODING_BOMS = {
+    b'\xff\xfe\x00\x00': 'utf-32-le',
+    b'\x00\x00\xfe\xff': 'utf-32-be',
+    b'\xef\xbb\xbf': 'utf-8-sig',
     b'\xff\xfe': 'utf-16-le',
     b'\xfe\xff': 'utf-16-be',
-    b'\00\00\xff\xfe': 'utf-32-le',
-    b'\00\00\xfe\xff': 'utf-32-be',
 }
 
 
-def detect_unicode_encoding(path):
-    """Attempts to guess the unicode encoding of a file based on the BOM.
+def detect_file_encoding(path, max_bytes_to_read=1024*256):
+    """Attempts to guess the unicode encoding of a file based on the BOM, and
+    depending on avalibility, using a charset detection method.
 
-    Assumes UTF-8 by default if there is no BOM.
+    Assumes UTF-8 by default if no other encoding is detected.
 
     Args:
         path: The path to the file
+        max_bytes_to_read: Maximum bytes to read from the file during encoding
+        detection.
 
     Returns: The encoding as a string, e.g. "utf-16-le" or "utf-8"
     """
@@ -1192,4 +1191,19 @@ def detect_unicode_encoding(path):
         for bom, encoding in ENCODING_BOMS.items():
             if first_bytes.startswith(bom):
                 return encoding
-        return 'utf-8'
+
+        if detect is None:
+            return 'utf-8'
+
+        f.seek(0)
+        result = detect(f.read(max_bytes_to_read))
+        if result['encoding'] is None:
+            log.warning("Couldn't detect encoding for file %r", path)
+            encoding = 'utf-8'
+        elif result['encoding'].lower() == 'ascii':
+            # Treat ASCII as UTF-8 (an ASCII document is also valid UTF-8)
+            encoding = 'utf-8'
+        else:
+            encoding = result['encoding'].lower()
+
+        return encoding
