@@ -5,7 +5,7 @@
 # Copyright (C) 2012 Frederik “Freso” S. Olesen
 # Copyright (C) 2013-2014, 2018-2022 Laurent Monin
 # Copyright (C) 2017 Sambhav Kothari
-# Copyright (C) 2017-2022 Philipp Wolfer
+# Copyright (C) 2017-2022, 2024 Philipp Wolfer
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,8 +26,12 @@ import builtins
 import gettext
 import locale
 import os
+import re
 
-from PyQt5.QtCore import QLocale
+from PyQt5.QtCore import (
+    QCollator,
+    QLocale,
+)
 
 from picard.const.sys import (
     IS_MACOS,
@@ -39,6 +43,9 @@ builtins.__dict__['N_'] = lambda a: a
 
 
 _logger = None
+_qcollator = QCollator()
+_qcollator_numeric = QCollator()
+_qcollator_numeric.setNumericMode(True)
 
 
 def set_locale_from_env():
@@ -133,7 +140,7 @@ def _log_lang_env_vars():
 
 def setup_gettext(localedir, ui_language=None, logger=None):
     """Setup locales, load translations, install gettext functions."""
-    global _logger
+    global _logger, _qcollator, _qcollator_numeric
     if not logger:
         _logger = lambda *a, **b: None  # noqa: E731
     else:
@@ -170,6 +177,9 @@ def setup_gettext(localedir, ui_language=None, logger=None):
 
     _logger("Using locale: %r", current_locale)
     QLocale.setDefault(QLocale(current_locale))
+    _qcollator = QCollator()
+    _qcollator_numeric = QCollator()
+    _qcollator_numeric.setNumericMode(True)
 
     trans = _load_translation('picard', localedir, language=current_locale)
     trans_attributes = _load_translation('picard-attributes', localedir, language=current_locale)
@@ -214,3 +224,55 @@ def gettext_ctxt(gettext_, message, context=None):
         # no translation found, return original message
         return message
     return translated
+
+
+def sort_key(string, numeric=False):
+    """Transforms a string to one that can be used in locale-aware comparisons.
+
+    Args:
+        string: The string to convert
+        numeric: Boolean indicating whether to use number aware sorting (natural sorting)
+
+    Returns: An object that can be compared locale-aware
+    """
+    # QCollator.sortKey is broken, see https://bugreports.qt.io/browse/QTBUG-128170
+    if IS_WIN:
+        return _sort_key_strxfrm(string, numeric)
+    else:
+        return _sort_key_qt(string, numeric)
+
+
+RE_NUMBER = re.compile(r'(\d+)')
+
+
+def _digits_replace(matchobj):
+    s = matchobj.group(0)
+    return str(int(s)) if s.isdecimal() else s
+
+
+def _sort_key_qt(string, numeric=False):
+    collator = _qcollator_numeric if numeric else _qcollator
+    # On macOS / Windows the numeric sorting does not work reliable with non-latin
+    # scripts. Replace numbers in the sort string with their latin equivalent.
+    if numeric and (IS_MACOS or IS_WIN):
+        string = RE_NUMBER.sub(_digits_replace, string)
+
+    # On macOS numeric sorting of strings entirely consisting of numeric characters fails
+    # and always sorts alphabetically (002 < 1). Always prefix with an alphabetic character
+    # to work around that.
+    return collator.sortKey('a' + string.replace('\0', ''))
+
+
+def _sort_key_strxfrm(string, numeric=False):
+    if numeric:
+        return [int(s) if s.isdecimal() else _strxfrm(s)
+            for s in RE_NUMBER.split(str(string).replace('\0', ''))]
+    else:
+        return _strxfrm(string)
+
+
+def _strxfrm(string):
+    try:
+        return locale.strxfrm(string)
+    except (OSError, ValueError):
+        return string.lower()
